@@ -25,26 +25,24 @@ class ModifyLogServiceStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'waf-openapi', '2019-09-10', 'ModifyLogServiceStatus','waf')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Enabled(self):
+	def get_Enabled(self): # Integer
 		return self.get_query_params().get('Enabled')
 
-	def set_Enabled(self,Enabled):
-		self.add_query_param('Enabled',Enabled)
-
-	def get_InstanceId(self):
+	def set_Enabled(self, Enabled):  # Integer
+		self.add_query_param('Enabled', Enabled)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_Domain(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_Domain(self): # String
 		return self.get_query_params().get('Domain')
 
-	def set_Domain(self,Domain):
-		self.add_query_param('Domain',Domain)
\ No newline at end of file
+	def set_Domain(self, Domain):  # String
+		self.add_query_param('Domain', Domain)
