@@ -25,44 +25,39 @@ class ModifyProtectionRuleStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'waf-openapi', '2019-09-10', 'ModifyProtectionRuleStatus','waf')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LockVersion(self):
+	def get_LockVersion(self): # Long
 		return self.get_query_params().get('LockVersion')
 
-	def set_LockVersion(self,LockVersion):
-		self.add_query_param('LockVersion',LockVersion)
-
-	def get_DefenseType(self):
+	def set_LockVersion(self, LockVersion):  # Long
+		self.add_query_param('LockVersion', LockVersion)
+	def get_DefenseType(self): # String
 		return self.get_query_params().get('DefenseType')
 
-	def set_DefenseType(self,DefenseType):
-		self.add_query_param('DefenseType',DefenseType)
-
-	def get_RuleStatus(self):
+	def set_DefenseType(self, DefenseType):  # String
+		self.add_query_param('DefenseType', DefenseType)
+	def get_RuleStatus(self): # Integer
 		return self.get_query_params().get('RuleStatus')
 
-	def set_RuleStatus(self,RuleStatus):
-		self.add_query_param('RuleStatus',RuleStatus)
-
-	def get_InstanceId(self):
+	def set_RuleStatus(self, RuleStatus):  # Integer
+		self.add_query_param('RuleStatus', RuleStatus)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_Domain(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_Domain(self): # String
 		return self.get_query_params().get('Domain')
 
-	def set_Domain(self,Domain):
-		self.add_query_param('Domain',Domain)
-
-	def get_RuleId(self):
+	def set_Domain(self, Domain):  # String
+		self.add_query_param('Domain', Domain)
+	def get_RuleId(self): # Long
 		return self.get_query_params().get('RuleId')
 
-	def set_RuleId(self,RuleId):
-		self.add_query_param('RuleId',RuleId)
\ No newline at end of file
+	def set_RuleId(self, RuleId):  # Long
+		self.add_query_param('RuleId', RuleId)
